@@ -6,7 +6,7 @@ set -o pipefail
 BASE_DIR=$(cd $(dirname "$0")/.. && pwd)
 
 # then execute tests for elements
-export DIB_CMD="disk-image-create"
+export DIB_CMD="diskimage-builder"
 export DIB_ELEMENTS=$(python -c '
 import diskimage_builder.paths
 diskimage_builder.paths.show_path("elements")')
@@ -26,7 +26,7 @@ DEFAULT_SKIP_TESTS=(
     # These require "zypper" on the host which is not available on
     # all platforms
     opensuse-minimal/build-succeeds
-    opensuse-minimal/opensuse151-build-succeeds
+    opensuse-minimal/opensuse15-build-succeeds
     # non-voting; not used by infra currently
     gentoo/build-succeeds
     # Needs infra mirroring to move to voting job
@@ -38,7 +38,7 @@ DEFAULT_SKIP_TESTS=(
     # in the gate.  Keep them in a -nv job until we can figure out
     # better caching for the images
     opensuse/build-succeeds
-    opensuse/opensuse151-build-succeeds
+    opensuse/opensuse15-build-succeeds
     centos7/build-succeeds
     debian/build-succeeds
     fedora/build-succeeds
@@ -111,13 +111,11 @@ function wait_minus_n {
 # in results which tests have failed.
 function logfile_status {
     local status="$1"
-    local arg="$2"
-    local filename
-    if [[ -z "${arg// }" ]]; then
+    local filename="$2"
+    if [[ -z "${filename}" ]]; then
         return
     fi
 
-    filename="$(echo $arg | cut -f2 -d' ')"
     echo "Moving ${filename} to ${filename/.log/.$status.log}"
     mv "$filename" ${filename/.log/.$status.log}
 }
@@ -132,25 +130,30 @@ function run_disk_element_test() {
     local output_format="$4"
     local logfile="$5"
 
-    local use_tmp_flag=""
     local dest_dir=$(mktemp -d)
 
     if [[ ${KEEP_OUTPUT} -ne 1 ]]; then
         trap "rm -rf $dest_dir" EXIT
     fi
 
-    if [ "${dont_use_tmp}" = "yes" ]; then
-        use_tmp_flag="--no-tmpfs"
-    fi
+    cat >> $dest_dir/image.yaml << EOF
+- imagename: $dest_dir/image
+  debug-trace: 1
+  types: [$output_format]
+  no-tmpfs: $dont_use_tmp
+  logfile: $logfile
+  skip-base: yes
+  elements:
+  - $element
+  - $test_element
+  environment:
+    DIB_SHOW_IMAGE_USAGE: "1"
+EOF
 
     if break="after-error" break_outside_target=1 \
         break_cmd="cp -v \$TMP_MOUNT_PATH/tmp/dib-test-should-fail ${dest_dir} || true" \
-        DIB_SHOW_IMAGE_USAGE=1 \
         ELEMENTS_PATH=$DIB_ELEMENTS/$element/test-elements \
-        $DIB_CMD -x -t ${output_format} \
-                       ${use_tmp_flag} \
-                       ${logfile} \
-                       -o $dest_dir/image -n $element $test_element 2>&1 \
+        $DIB_CMD $dest_dir/image.yaml 2>&1 \
            | log_with_prefix "${element}/${test_element}"; then
 
         if [[ "qcow2" =~ "$output_format" ]]; then
@@ -162,22 +165,25 @@ function run_disk_element_test() {
             fi
         fi
 
-        # check inside the tar for sentinel files
-        if ! [ -f "$dest_dir/image.tar" ]; then
-            echo "Error: Build failed for element: $element, test-element: $test_element."
-            echo "No image $dest_dir/image.tar found!"
-            logfile_status "FAIL" "${logfile}"
-            exit 1
-        else
-            if tar -tf $dest_dir/image.tar | grep -q /tmp/dib-test-should-fail; then
-                echo "Error: Element: $element, test-element $test_element should have failed, but passed."
+        if [[ "tar" =~ "$output_format" ]]; then
+            # check inside the tar for sentinel files
+            if ! [ -f "$dest_dir/image.tar" ]; then
+                echo "Error: Build failed for element: $element, test-element: $test_element."
+                echo "No image $dest_dir/image.tar found!"
                 logfile_status "FAIL" "${logfile}"
                 exit 1
             else
-                echo "PASS: Element $element, test-element: $test_element"
-                logfile_status "PASS" "${logfile}"
+                if tar -tf $dest_dir/image.tar | grep -q /tmp/dib-test-should-fail; then
+                    echo "Error: Element: $element, test-element $test_element should have failed, but passed."
+                    logfile_status "FAIL" "${logfile}"
+                    exit 1
+                fi
             fi
         fi
+
+        # if we got here, the test passed
+        echo "PASS: Element $element, test-element: $test_element"
+        logfile_status "PASS" "${logfile}"
     else
         if [ -f "${dest_dir}/dib-test-should-fail" ]; then
             echo "PASS: Element $element, test-element: $test_element"
@@ -209,16 +215,18 @@ function run_ramdisk_element_test() {
     local logfile="$5"
     local dest_dir=$(mktemp -d)
 
-    local use_tmp_flag=""
-    if [ "${dont_use_tmp}" = "yes" ]; then
-        use_tmp_flag="--no-tmpfs"
-    fi
+    cat >> $dest_dir/image.yaml << EOF
+- imagename: $dest_dir/image
+  debug-trace: 1
+  no-tmpfs: $dont_use_tmp
+  logfile: $logfile
+  elements:
+  - $element
+  - $test_element
+EOF
 
     if ELEMENTS_PATH=$DIB_ELEMENTS/$element/test-elements \
-        $DIB_CMD -x -o ${dest_dir}/image \
-                       ${logfile} \
-                       ${use_tmp_flag} \
-                       ${element} ${test_element} 2>&1 \
+        $DIB_CMD $dest_dir/image.yaml 2>&1 \
             | log_with_prefix "${element}/${test_element}"; then
         # TODO(dtantsur): test also kernel presence once we sort out its naming
         # problem (vmlinuz vs kernel)
@@ -413,9 +421,9 @@ for test in "${TESTS_TO_RUN[@]}"; do
         element_output=$(cat ${element_output_override})
     fi
 
-    log_argument=' '
+    log_argument=''
     if [[ -n "${LOG_DIRECTORY}" ]]; then
-        log_argument="--logfile ${LOG_DIRECTORY}/${element}_${test_element}.log"
+        log_argument="${LOG_DIRECTORY}/${element}_${test_element}.log"
     fi
 
     echo "Running $test ($element_type)"
